@@ -20,7 +20,7 @@ Sec-WebSocket-Version: 13
 
 #ifndef __FreeBSD__
 #define _POSIX_C_SOURCE 1 /* fileno() */
-#define _BSD_SOURCE /* strdup() */
+#define _DEFAULT_SOURCE /* strdup() */
 #define _DARWIN_C_SOURCE /* strdup() on OS X */
 #endif
 #ifdef __linux__
