@@ -22,7 +22,7 @@ THE SOFTWARE.
 */
 
 #ifndef __FreeBSD__
-#define _BSD_SOURCE /* required by strdup() */
+#define _DEFAULT_SOURCE /* required by strdup() */
 #define _DARWIN_C_SOURCE /* strdup() on OS X */
 #endif
 
