@@ -8,7 +8,7 @@
  */
 
 #ifndef __FreeBSD__
-#define _BSD_SOURCE /* snprintf() */
+#define _DEFAULT_SOURCE /* snprintf() */
 #endif
 
 #include <config.h>
